# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/geo/Province.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.geo import USState_pb2 as opencannabis_dot_geo_dot_USState__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/geo/Province.proto',
  package='opencannabis.geo',
  syntax='proto3',
  serialized_options=b'\n\032io.opencannabis.schema.geoH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fopencannabis/geo/Province.proto\x12\x10opencannabis.geo\x1a\x1eopencannabis/geo/USState.proto\"V\n\x08Province\x12.\n\x05state\x18\x01 \x01(\x0e\x32\x1d.opencannabis.geo.usa.USStateH\x00\x12\x12\n\x08province\x18\x02 \x01(\tH\x00\x42\x06\n\x04specB&\n\x1aio.opencannabis.schema.geoH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_geo_dot_USState__pb2.DESCRIPTOR,])




_PROVINCE = _descriptor.Descriptor(
  name='Province',
  full_name='opencannabis.geo.Province',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='opencannabis.geo.Province.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='province', full_name='opencannabis.geo.Province.province', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='spec', full_name='opencannabis.geo.Province.spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=85,
  serialized_end=171,
)

_PROVINCE.fields_by_name['state'].enum_type = opencannabis_dot_geo_dot_USState__pb2._USSTATE
_PROVINCE.oneofs_by_name['spec'].fields.append(
  _PROVINCE.fields_by_name['state'])
_PROVINCE.fields_by_name['state'].containing_oneof = _PROVINCE.oneofs_by_name['spec']
_PROVINCE.oneofs_by_name['spec'].fields.append(
  _PROVINCE.fields_by_name['province'])
_PROVINCE.fields_by_name['province'].containing_oneof = _PROVINCE.oneofs_by_name['spec']
DESCRIPTOR.message_types_by_name['Province'] = _PROVINCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Province = _reflection.GeneratedProtocolMessageType('Province', (_message.Message,), {
  'DESCRIPTOR' : _PROVINCE,
  '__module__' : 'opencannabis.geo.Province_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.geo.Province)
  })
_sym_db.RegisterMessage(Province)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/products/Preroll.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.base import ProductKey_pb2 as opencannabis_dot_base_dot_ProductKey__pb2
from opencannabis.content import MaterialsData_pb2 as opencannabis_dot_content_dot_MaterialsData__pb2
from opencannabis.content import ProductContent_pb2 as opencannabis_dot_content_dot_ProductContent__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/products/Preroll.proto',
  package='opencannabis.products',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.productB\016PrerollProductH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#opencannabis/products/Preroll.proto\x12\x15opencannabis.products\x1a\"opencannabis/base/ProductKey.proto\x1a(opencannabis/content/MaterialsData.proto\x1a)opencannabis/content/ProductContent.proto\"\xa7\x03\n\x07Preroll\x12*\n\x03key\x18\x01 \x01(\x0b\x32\x1d.opencannabis.base.ProductKey\x12\x33\n\x06\x66lower\x18\x02 \x01(\x0b\x32#.opencannabis.base.ProductReference\x12\x0e\n\x06length\x18\x03 \x01(\x01\x12\x11\n\tthickness\x18\x04 \x01(\x01\x12\x32\n\x05\x66lags\x18\x05 \x03(\x0e\x32#.opencannabis.products.Preroll.Flag\x12\x35\n\x07product\x18\x06 \x01(\x0b\x32$.opencannabis.content.ProductContent\x12\x35\n\x08material\x18\x07 \x01(\x0b\x32#.opencannabis.content.MaterialsData\"v\n\x04\x46lag\x12\x14\n\x10NO_PREROLL_FLAGS\x10\x00\x12\x10\n\x0cHASH_INFUSED\x10\x01\x12\x10\n\x0cKIEF_INFUSED\x10\x02\x12\r\n\tFORTIFIED\x10\x03\x12\x0f\n\x0b\x46ULL_FLOWER\x10\x04\x12\x14\n\x10\x43ONTAINS_TOBACCO\x10\x05\x42:\n\x1eio.opencannabis.schema.productB\x0ePrerollProductH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_base_dot_ProductKey__pb2.DESCRIPTOR,opencannabis_dot_content_dot_MaterialsData__pb2.DESCRIPTOR,opencannabis_dot_content_dot_ProductContent__pb2.DESCRIPTOR,])



_PREROLL_FLAG = _descriptor.EnumDescriptor(
  name='Flag',
  full_name='opencannabis.products.Preroll.Flag',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_PREROLL_FLAGS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HASH_INFUSED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KIEF_INFUSED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORTIFIED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FULL_FLOWER', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTAINS_TOBACCO', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=489,
  serialized_end=607,
)
_sym_db.RegisterEnumDescriptor(_PREROLL_FLAG)


_PREROLL = _descriptor.Descriptor(
  name='Preroll',
  full_name='opencannabis.products.Preroll',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.Preroll.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flower', full_name='opencannabis.products.Preroll.flower', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='opencannabis.products.Preroll.length', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thickness', full_name='opencannabis.products.Preroll.thickness', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='opencannabis.products.Preroll.flags', index=4,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product', full_name='opencannabis.products.Preroll.product', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='material', full_name='opencannabis.products.Preroll.material', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PREROLL_FLAG,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=184,
  serialized_end=607,
)

_PREROLL.fields_by_name['key'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTKEY
_PREROLL.fields_by_name['flower'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTREFERENCE
_PREROLL.fields_by_name['flags'].enum_type = _PREROLL_FLAG
_PREROLL.fields_by_name['product'].message_type = opencannabis_dot_content_dot_ProductContent__pb2._PRODUCTCONTENT
_PREROLL.fields_by_name['material'].message_type = opencannabis_dot_content_dot_MaterialsData__pb2._MATERIALSDATA
_PREROLL_FLAG.containing_type = _PREROLL
DESCRIPTOR.message_types_by_name['Preroll'] = _PREROLL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Preroll = _reflection.GeneratedProtocolMessageType('Preroll', (_message.Message,), {
  'DESCRIPTOR' : _PREROLL,
  '__module__' : 'opencannabis.products.Preroll_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.Preroll)
  })
_sym_db.RegisterMessage(Preroll)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/accounting/Taxes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.geo import Province_pb2 as opencannabis_dot_geo_dot_Province__pb2
from opencannabis.geo import Country_pb2 as opencannabis_dot_geo_dot_Country__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/accounting/Taxes.proto',
  package='opencannabis.taxes',
  syntax='proto3',
  serialized_options=b'\n!io.opencannabis.schema.accountingB\017AccountingTaxesH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#opencannabis/accounting/Taxes.proto\x12\x12opencannabis.taxes\x1a\x1fopencannabis/geo/Province.proto\x1a\x1eopencannabis/geo/Country.proto\"z\n\x08LocalTax\x12\x14\n\x0cmunicipality\x18\x01 \x01(\t\x12,\n\x08province\x18\x02 \x01(\x0b\x32\x1a.opencannabis.geo.Province\x12*\n\x07\x63ountry\x18\x03 \x01(\x0b\x32\x19.opencannabis.geo.Country\"i\n\rProvincialTax\x12,\n\x08province\x18\x01 \x01(\x0b\x32\x1a.opencannabis.geo.Province\x12*\n\x07\x63ountry\x18\x02 \x01(\x0b\x32\x19.opencannabis.geo.Country\"8\n\nFederalTax\x12*\n\x07\x63ountry\x18\x01 \x01(\x0b\x32\x19.opencannabis.geo.Country\"\xf3\x01\n\x0fTaxJurisdiction\x12\x35\n\x04mode\x18\x01 \x01(\x0e\x32\'.opencannabis.taxes.TaxJurisdictionMode\x12-\n\x05local\x18\x02 \x01(\x0b\x32\x1c.opencannabis.taxes.LocalTaxH\x00\x12\x37\n\nprovincial\x18\x03 \x01(\x0b\x32!.opencannabis.taxes.ProvincialTaxH\x00\x12\x31\n\x07\x66\x65\x64\x65ral\x18\x04 \x01(\x0b\x32\x1e.opencannabis.taxes.FederalTaxH\x00\x42\x0e\n\x0cjurisdiction\"\xc2\x01\n\x07TaxSpec\x12+\n\x05\x62\x61sis\x18\x01 \x01(\x0e\x32\x1c.opencannabis.taxes.TaxBasis\x12\x39\n\x0cjurisdiction\x18\x02 \x01(\x0b\x32#.opencannabis.taxes.TaxJurisdiction\x12\x19\n\x11transaction_label\x18\x03 \x01(\t\x12\x14\n\npercentage\x18\x04 \x01(\x01H\x00\x12\x16\n\x0cstatic_value\x18\x05 \x01(\x01H\x00\x42\x06\n\x04rate\"n\n\x03Tax\x12\n\n\x02id\x18\x01 \x01(\t\x12)\n\x04spec\x18\x02 \x01(\x0b\x32\x1b.opencannabis.taxes.TaxSpec\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05label\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t*;\n\x13TaxJurisdictionMode\x12\t\n\x05LOCAL\x10\x00\x12\x0c\n\x08PROVINCE\x10\x01\x12\x0b\n\x07\x46\x45\x44\x45RAL\x10\x02*9\n\x08TaxBasis\x12\x08\n\x04ITEM\x10\x00\x12\x12\n\x0eORDER_SUBTOTAL\x10\x01\x12\x0f\n\x0bORDER_TOTAL\x10\x02\x42>\n!io.opencannabis.schema.accountingB\x0f\x41\x63\x63ountingTaxesH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_geo_dot_Province__pb2.DESCRIPTOR,opencannabis_dot_geo_dot_Country__pb2.DESCRIPTOR,])

_TAXJURISDICTIONMODE = _descriptor.EnumDescriptor(
  name='TaxJurisdictionMode',
  full_name='opencannabis.taxes.TaxJurisdictionMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOCAL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROVINCE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEDERAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=968,
  serialized_end=1027,
)
_sym_db.RegisterEnumDescriptor(_TAXJURISDICTIONMODE)

TaxJurisdictionMode = enum_type_wrapper.EnumTypeWrapper(_TAXJURISDICTIONMODE)
_TAXBASIS = _descriptor.EnumDescriptor(
  name='TaxBasis',
  full_name='opencannabis.taxes.TaxBasis',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ITEM', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORDER_SUBTOTAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORDER_TOTAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1029,
  serialized_end=1086,
)
_sym_db.RegisterEnumDescriptor(_TAXBASIS)

TaxBasis = enum_type_wrapper.EnumTypeWrapper(_TAXBASIS)
LOCAL = 0
PROVINCE = 1
FEDERAL = 2
ITEM = 0
ORDER_SUBTOTAL = 1
ORDER_TOTAL = 2



_LOCALTAX = _descriptor.Descriptor(
  name='LocalTax',
  full_name='opencannabis.taxes.LocalTax',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='municipality', full_name='opencannabis.taxes.LocalTax.municipality', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='province', full_name='opencannabis.taxes.LocalTax.province', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country', full_name='opencannabis.taxes.LocalTax.country', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=246,
)


_PROVINCIALTAX = _descriptor.Descriptor(
  name='ProvincialTax',
  full_name='opencannabis.taxes.ProvincialTax',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='province', full_name='opencannabis.taxes.ProvincialTax.province', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country', full_name='opencannabis.taxes.ProvincialTax.country', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=353,
)


_FEDERALTAX = _descriptor.Descriptor(
  name='FederalTax',
  full_name='opencannabis.taxes.FederalTax',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='country', full_name='opencannabis.taxes.FederalTax.country', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=355,
  serialized_end=411,
)


_TAXJURISDICTION = _descriptor.Descriptor(
  name='TaxJurisdiction',
  full_name='opencannabis.taxes.TaxJurisdiction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='opencannabis.taxes.TaxJurisdiction.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local', full_name='opencannabis.taxes.TaxJurisdiction.local', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provincial', full_name='opencannabis.taxes.TaxJurisdiction.provincial', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='federal', full_name='opencannabis.taxes.TaxJurisdiction.federal', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='jurisdiction', full_name='opencannabis.taxes.TaxJurisdiction.jurisdiction',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=414,
  serialized_end=657,
)


_TAXSPEC = _descriptor.Descriptor(
  name='TaxSpec',
  full_name='opencannabis.taxes.TaxSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='basis', full_name='opencannabis.taxes.TaxSpec.basis', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jurisdiction', full_name='opencannabis.taxes.TaxSpec.jurisdiction', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_label', full_name='opencannabis.taxes.TaxSpec.transaction_label', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='opencannabis.taxes.TaxSpec.percentage', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static_value', full_name='opencannabis.taxes.TaxSpec.static_value', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='rate', full_name='opencannabis.taxes.TaxSpec.rate',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=660,
  serialized_end=854,
)


_TAX = _descriptor.Descriptor(
  name='Tax',
  full_name='opencannabis.taxes.Tax',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='opencannabis.taxes.Tax.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='opencannabis.taxes.Tax.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.taxes.Tax.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='opencannabis.taxes.Tax.label', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='opencannabis.taxes.Tax.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=856,
  serialized_end=966,
)

_LOCALTAX.fields_by_name['province'].message_type = opencannabis_dot_geo_dot_Province__pb2._PROVINCE
_LOCALTAX.fields_by_name['country'].message_type = opencannabis_dot_geo_dot_Country__pb2._COUNTRY
_PROVINCIALTAX.fields_by_name['province'].message_type = opencannabis_dot_geo_dot_Province__pb2._PROVINCE
_PROVINCIALTAX.fields_by_name['country'].message_type = opencannabis_dot_geo_dot_Country__pb2._COUNTRY
_FEDERALTAX.fields_by_name['country'].message_type = opencannabis_dot_geo_dot_Country__pb2._COUNTRY
_TAXJURISDICTION.fields_by_name['mode'].enum_type = _TAXJURISDICTIONMODE
_TAXJURISDICTION.fields_by_name['local'].message_type = _LOCALTAX
_TAXJURISDICTION.fields_by_name['provincial'].message_type = _PROVINCIALTAX
_TAXJURISDICTION.fields_by_name['federal'].message_type = _FEDERALTAX
_TAXJURISDICTION.oneofs_by_name['jurisdiction'].fields.append(
  _TAXJURISDICTION.fields_by_name['local'])
_TAXJURISDICTION.fields_by_name['local'].containing_oneof = _TAXJURISDICTION.oneofs_by_name['jurisdiction']
_TAXJURISDICTION.oneofs_by_name['jurisdiction'].fields.append(
  _TAXJURISDICTION.fields_by_name['provincial'])
_TAXJURISDICTION.fields_by_name['provincial'].containing_oneof = _TAXJURISDICTION.oneofs_by_name['jurisdiction']
_TAXJURISDICTION.oneofs_by_name['jurisdiction'].fields.append(
  _TAXJURISDICTION.fields_by_name['federal'])
_TAXJURISDICTION.fields_by_name['federal'].containing_oneof = _TAXJURISDICTION.oneofs_by_name['jurisdiction']
_TAXSPEC.fields_by_name['basis'].enum_type = _TAXBASIS
_TAXSPEC.fields_by_name['jurisdiction'].message_type = _TAXJURISDICTION
_TAXSPEC.oneofs_by_name['rate'].fields.append(
  _TAXSPEC.fields_by_name['percentage'])
_TAXSPEC.fields_by_name['percentage'].containing_oneof = _TAXSPEC.oneofs_by_name['rate']
_TAXSPEC.oneofs_by_name['rate'].fields.append(
  _TAXSPEC.fields_by_name['static_value'])
_TAXSPEC.fields_by_name['static_value'].containing_oneof = _TAXSPEC.oneofs_by_name['rate']
_TAX.fields_by_name['spec'].message_type = _TAXSPEC
DESCRIPTOR.message_types_by_name['LocalTax'] = _LOCALTAX
DESCRIPTOR.message_types_by_name['ProvincialTax'] = _PROVINCIALTAX
DESCRIPTOR.message_types_by_name['FederalTax'] = _FEDERALTAX
DESCRIPTOR.message_types_by_name['TaxJurisdiction'] = _TAXJURISDICTION
DESCRIPTOR.message_types_by_name['TaxSpec'] = _TAXSPEC
DESCRIPTOR.message_types_by_name['Tax'] = _TAX
DESCRIPTOR.enum_types_by_name['TaxJurisdictionMode'] = _TAXJURISDICTIONMODE
DESCRIPTOR.enum_types_by_name['TaxBasis'] = _TAXBASIS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LocalTax = _reflection.GeneratedProtocolMessageType('LocalTax', (_message.Message,), {
  'DESCRIPTOR' : _LOCALTAX,
  '__module__' : 'opencannabis.accounting.Taxes_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.taxes.LocalTax)
  })
_sym_db.RegisterMessage(LocalTax)

ProvincialTax = _reflection.GeneratedProtocolMessageType('ProvincialTax', (_message.Message,), {
  'DESCRIPTOR' : _PROVINCIALTAX,
  '__module__' : 'opencannabis.accounting.Taxes_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.taxes.ProvincialTax)
  })
_sym_db.RegisterMessage(ProvincialTax)

FederalTax = _reflection.GeneratedProtocolMessageType('FederalTax', (_message.Message,), {
  'DESCRIPTOR' : _FEDERALTAX,
  '__module__' : 'opencannabis.accounting.Taxes_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.taxes.FederalTax)
  })
_sym_db.RegisterMessage(FederalTax)

TaxJurisdiction = _reflection.GeneratedProtocolMessageType('TaxJurisdiction', (_message.Message,), {
  'DESCRIPTOR' : _TAXJURISDICTION,
  '__module__' : 'opencannabis.accounting.Taxes_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.taxes.TaxJurisdiction)
  })
_sym_db.RegisterMessage(TaxJurisdiction)

TaxSpec = _reflection.GeneratedProtocolMessageType('TaxSpec', (_message.Message,), {
  'DESCRIPTOR' : _TAXSPEC,
  '__module__' : 'opencannabis.accounting.Taxes_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.taxes.TaxSpec)
  })
_sym_db.RegisterMessage(TaxSpec)

Tax = _reflection.GeneratedProtocolMessageType('Tax', (_message.Message,), {
  'DESCRIPTOR' : _TAX,
  '__module__' : 'opencannabis.accounting.Taxes_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.taxes.Tax)
  })
_sym_db.RegisterMessage(Tax)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/products/Flower.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.base import ProductKey_pb2 as opencannabis_dot_base_dot_ProductKey__pb2
from opencannabis.content import MaterialsData_pb2 as opencannabis_dot_content_dot_MaterialsData__pb2
from opencannabis.content import ProductContent_pb2 as opencannabis_dot_content_dot_ProductContent__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/products/Flower.proto',
  package='opencannabis.products',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.productB\rFlowerProductH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"opencannabis/products/Flower.proto\x12\x15opencannabis.products\x1a\x19gust/core/datamodel.proto\x1a\"opencannabis/base/ProductKey.proto\x1a(opencannabis/content/MaterialsData.proto\x1a)opencannabis/content/ProductContent.proto\"\xae\x04\n\x06\x46lower\x12Y\n\x03key\x18\x01 \x01(\x0b\x32\x1d.opencannabis.base.ProductKeyB-\xc2\xb5\x03)\x12\'Key that uniquely identifies a product.\x12t\n\x07product\x18\x02 \x01(\x0b\x32$.opencannabis.content.ProductContentB=\xc2\xb5\x03\x39\x12\x37Specifies product-level information or collateral data.\x12\x81\x01\n\x08material\x18\x03 \x01(\x0b\x32#.opencannabis.content.MaterialsDataBJ\xc2\xb5\x03\x46\x12\x44Specifies information about the material that constitutes a product.\x12\x8c\x01\n\x04type\x18\x04 \x01(\x0e\x32\".opencannabis.products.Flower.TypeBZ\xc2\xb5\x03V\x12TSpecifies the specialized type of flower (TRIMMED, SHAKE, SMALL_NUGS, PREMIUM_NUGS).\"@\n\x04Type\x12\x0b\n\x07TRIMMED\x10\x00\x12\t\n\x05SHAKE\x10\x01\x12\x0e\n\nSMALL_NUGS\x10\x02\x12\x10\n\x0cPREMIUM_NUGS\x10\x03\x42\x39\n\x1eio.opencannabis.schema.productB\rFlowerProductH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_base_dot_ProductKey__pb2.DESCRIPTOR,opencannabis_dot_content_dot_MaterialsData__pb2.DESCRIPTOR,opencannabis_dot_content_dot_ProductContent__pb2.DESCRIPTOR,])



_FLOWER_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='opencannabis.products.Flower.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRIMMED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHAKE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMALL_NUGS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREMIUM_NUGS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=704,
  serialized_end=768,
)
_sym_db.RegisterEnumDescriptor(_FLOWER_TYPE)


_FLOWER = _descriptor.Descriptor(
  name='Flower',
  full_name='opencannabis.products.Flower',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.Flower.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003)\022\'Key that uniquely identifies a product.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product', full_name='opencannabis.products.Flower.product', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0039\0227Specifies product-level information or collateral data.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='material', full_name='opencannabis.products.Flower.material', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003F\022DSpecifies information about the material that constitutes a product.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.products.Flower.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003V\022TSpecifies the specialized type of flower (TRIMMED, SHAKE, SMALL_NUGS, PREMIUM_NUGS).', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FLOWER_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=210,
  serialized_end=768,
)

_FLOWER.fields_by_name['key'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTKEY
_FLOWER.fields_by_name['product'].message_type = opencannabis_dot_content_dot_ProductContent__pb2._PRODUCTCONTENT
_FLOWER.fields_by_name['material'].message_type = opencannabis_dot_content_dot_MaterialsData__pb2._MATERIALSDATA
_FLOWER.fields_by_name['type'].enum_type = _FLOWER_TYPE
_FLOWER_TYPE.containing_type = _FLOWER
DESCRIPTOR.message_types_by_name['Flower'] = _FLOWER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Flower = _reflection.GeneratedProtocolMessageType('Flower', (_message.Message,), {
  'DESCRIPTOR' : _FLOWER,
  '__module__' : 'opencannabis.products.Flower_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.Flower)
  })
_sym_db.RegisterMessage(Flower)


DESCRIPTOR._options = None
_FLOWER.fields_by_name['key']._options = None
_FLOWER.fields_by_name['product']._options = None
_FLOWER.fields_by_name['material']._options = None
_FLOWER.fields_by_name['type']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/products/distribution/DistributionChannel.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/products/distribution/DistributionChannel.proto',
  package='opencannabis.products.distribution',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.productB\023DistributionChannelH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<opencannabis/products/distribution/DistributionChannel.proto\x12\"opencannabis.products.distribution\"\xb4\x01\n\x12\x44istributionPolicy\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12<\n\x07\x63hannel\x18\x02 \x01(\x0e\x32+.opencannabis.products.distribution.Channel\x12=\n\x04type\x18\x03 \x01(\x0e\x32/.opencannabis.products.distribution.ChannelType\x12\x10\n\x08suppress\x18\x04 \x01(\x08*G\n\x07\x43hannel\x12\x17\n\x13UNSPECIFIED_CHANNEL\x10\x00\x12\n\n\x06RETAIL\x10\x01\x12\r\n\tWHOLESALE\x10\x02\x12\x08\n\x04\x42ULK\x10\x03*H\n\x0b\x43hannelType\x12\x1c\n\x18UNSPECIFIED_CHANNEL_TYPE\x10\x00\x12\n\n\x06\x44IRECT\x10\x01\x12\x0f\n\x0bMARKETPLACE\x10\x02\x42?\n\x1eio.opencannabis.schema.productB\x13\x44istributionChannelH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
)

_CHANNEL = _descriptor.EnumDescriptor(
  name='Channel',
  full_name='opencannabis.products.distribution.Channel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_CHANNEL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RETAIL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WHOLESALE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BULK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=283,
  serialized_end=354,
)
_sym_db.RegisterEnumDescriptor(_CHANNEL)

Channel = enum_type_wrapper.EnumTypeWrapper(_CHANNEL)
_CHANNELTYPE = _descriptor.EnumDescriptor(
  name='ChannelType',
  full_name='opencannabis.products.distribution.ChannelType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_CHANNEL_TYPE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIRECT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MARKETPLACE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=356,
  serialized_end=428,
)
_sym_db.RegisterEnumDescriptor(_CHANNELTYPE)

ChannelType = enum_type_wrapper.EnumTypeWrapper(_CHANNELTYPE)
UNSPECIFIED_CHANNEL = 0
RETAIL = 1
WHOLESALE = 2
BULK = 3
UNSPECIFIED_CHANNEL_TYPE = 0
DIRECT = 1
MARKETPLACE = 2



_DISTRIBUTIONPOLICY = _descriptor.Descriptor(
  name='DistributionPolicy',
  full_name='opencannabis.products.distribution.DistributionPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='opencannabis.products.distribution.DistributionPolicy.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel', full_name='opencannabis.products.distribution.DistributionPolicy.channel', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.products.distribution.DistributionPolicy.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='suppress', full_name='opencannabis.products.distribution.DistributionPolicy.suppress', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=281,
)

_DISTRIBUTIONPOLICY.fields_by_name['channel'].enum_type = _CHANNEL
_DISTRIBUTIONPOLICY.fields_by_name['type'].enum_type = _CHANNELTYPE
DESCRIPTOR.message_types_by_name['DistributionPolicy'] = _DISTRIBUTIONPOLICY
DESCRIPTOR.enum_types_by_name['Channel'] = _CHANNEL
DESCRIPTOR.enum_types_by_name['ChannelType'] = _CHANNELTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DistributionPolicy = _reflection.GeneratedProtocolMessageType('DistributionPolicy', (_message.Message,), {
  'DESCRIPTOR' : _DISTRIBUTIONPOLICY,
  '__module__' : 'opencannabis.products.distribution.DistributionChannel_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.distribution.DistributionPolicy)
  })
_sym_db.RegisterMessage(DistributionPolicy)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.proximity`
  ---------------------------
  Objects and protocol definitions for Bluetooth Low Energy (BLE) proximity.

"""

# `opencannabis.proximity`



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/structs/pricing/SaleDescriptor.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.temporal import Instant_pb2 as opencannabis_dot_temporal_dot_Instant__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/structs/pricing/SaleDescriptor.proto',
  package='opencannabis.structs.pricing',
  syntax='proto3',
  serialized_options=b'\n%io.opencannabis.schema.product.structB\017ProductDiscountH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1opencannabis/structs/pricing/SaleDescriptor.proto\x12\x1copencannabis.structs.pricing\x1a#opencannabis/temporal/Instant.proto\"&\n\x12PercentageDiscount\x12\x10\n\x08\x64iscount\x18\x14 \x01(\r\"/\n\x0c\x42OGODiscount\x12\x0f\n\x07trigger\x18\x15 \x01(\r\x12\x0e\n\x06reward\x18\x16 \x01(\r\"2\n\x0fLoyaltyDiscount\x12\x0f\n\x07trigger\x18\x17 \x01(\r\x12\x0e\n\x06reward\x18\x18 \x01(\r\"\xff\x02\n\x0eSaleDescriptor\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32&.opencannabis.structs.pricing.SaleType\x12\x31\n\teffective\x18\x02 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant\x12\x32\n\nexpiration\x18\x03 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant\x12J\n\x0epercentage_off\x18\x04 \x01(\x0b\x32\x30.opencannabis.structs.pricing.PercentageDiscountH\x00\x12:\n\x04\x62ogo\x18\x05 \x01(\x0b\x32*.opencannabis.structs.pricing.BOGODiscountH\x00\x12@\n\x07loyalty\x18\x06 \x01(\x0b\x32-.opencannabis.structs.pricing.LoyaltyDiscountH\x00\x42\x06\n\x04sale*P\n\x08SaleType\x12\x18\n\x14PERCENTAGE_REDUCTION\x10\x00\x12\x13\n\x0fVALUE_REDUCTION\x10\x01\x12\x08\n\x04\x42OGO\x10\x02\x12\x0b\n\x07LOYALTY\x10\x03\x42\x42\n%io.opencannabis.schema.product.structB\x0fProductDiscountH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_temporal_dot_Instant__pb2.DESCRIPTOR,])

_SALETYPE = _descriptor.EnumDescriptor(
  name='SaleType',
  full_name='opencannabis.structs.pricing.SaleType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PERCENTAGE_REDUCTION', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VALUE_REDUCTION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOGO', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOYALTY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=647,
  serialized_end=727,
)
_sym_db.RegisterEnumDescriptor(_SALETYPE)

SaleType = enum_type_wrapper.EnumTypeWrapper(_SALETYPE)
PERCENTAGE_REDUCTION = 0
VALUE_REDUCTION = 1
BOGO = 2
LOYALTY = 3



_PERCENTAGEDISCOUNT = _descriptor.Descriptor(
  name='PercentageDiscount',
  full_name='opencannabis.structs.pricing.PercentageDiscount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='discount', full_name='opencannabis.structs.pricing.PercentageDiscount.discount', index=0,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=158,
)


_BOGODISCOUNT = _descriptor.Descriptor(
  name='BOGODiscount',
  full_name='opencannabis.structs.pricing.BOGODiscount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trigger', full_name='opencannabis.structs.pricing.BOGODiscount.trigger', index=0,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward', full_name='opencannabis.structs.pricing.BOGODiscount.reward', index=1,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=207,
)


_LOYALTYDISCOUNT = _descriptor.Descriptor(
  name='LoyaltyDiscount',
  full_name='opencannabis.structs.pricing.LoyaltyDiscount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trigger', full_name='opencannabis.structs.pricing.LoyaltyDiscount.trigger', index=0,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward', full_name='opencannabis.structs.pricing.LoyaltyDiscount.reward', index=1,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=259,
)


_SALEDESCRIPTOR = _descriptor.Descriptor(
  name='SaleDescriptor',
  full_name='opencannabis.structs.pricing.SaleDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.structs.pricing.SaleDescriptor.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effective', full_name='opencannabis.structs.pricing.SaleDescriptor.effective', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration', full_name='opencannabis.structs.pricing.SaleDescriptor.expiration', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentage_off', full_name='opencannabis.structs.pricing.SaleDescriptor.percentage_off', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bogo', full_name='opencannabis.structs.pricing.SaleDescriptor.bogo', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loyalty', full_name='opencannabis.structs.pricing.SaleDescriptor.loyalty', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sale', full_name='opencannabis.structs.pricing.SaleDescriptor.sale',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=262,
  serialized_end=645,
)

_SALEDESCRIPTOR.fields_by_name['type'].enum_type = _SALETYPE
_SALEDESCRIPTOR.fields_by_name['effective'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_SALEDESCRIPTOR.fields_by_name['expiration'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_SALEDESCRIPTOR.fields_by_name['percentage_off'].message_type = _PERCENTAGEDISCOUNT
_SALEDESCRIPTOR.fields_by_name['bogo'].message_type = _BOGODISCOUNT
_SALEDESCRIPTOR.fields_by_name['loyalty'].message_type = _LOYALTYDISCOUNT
_SALEDESCRIPTOR.oneofs_by_name['sale'].fields.append(
  _SALEDESCRIPTOR.fields_by_name['percentage_off'])
_SALEDESCRIPTOR.fields_by_name['percentage_off'].containing_oneof = _SALEDESCRIPTOR.oneofs_by_name['sale']
_SALEDESCRIPTOR.oneofs_by_name['sale'].fields.append(
  _SALEDESCRIPTOR.fields_by_name['bogo'])
_SALEDESCRIPTOR.fields_by_name['bogo'].containing_oneof = _SALEDESCRIPTOR.oneofs_by_name['sale']
_SALEDESCRIPTOR.oneofs_by_name['sale'].fields.append(
  _SALEDESCRIPTOR.fields_by_name['loyalty'])
_SALEDESCRIPTOR.fields_by_name['loyalty'].containing_oneof = _SALEDESCRIPTOR.oneofs_by_name['sale']
DESCRIPTOR.message_types_by_name['PercentageDiscount'] = _PERCENTAGEDISCOUNT
DESCRIPTOR.message_types_by_name['BOGODiscount'] = _BOGODISCOUNT
DESCRIPTOR.message_types_by_name['LoyaltyDiscount'] = _LOYALTYDISCOUNT
DESCRIPTOR.message_types_by_name['SaleDescriptor'] = _SALEDESCRIPTOR
DESCRIPTOR.enum_types_by_name['SaleType'] = _SALETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PercentageDiscount = _reflection.GeneratedProtocolMessageType('PercentageDiscount', (_message.Message,), {
  'DESCRIPTOR' : _PERCENTAGEDISCOUNT,
  '__module__' : 'opencannabis.structs.pricing.SaleDescriptor_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.structs.pricing.PercentageDiscount)
  })
_sym_db.RegisterMessage(PercentageDiscount)

BOGODiscount = _reflection.GeneratedProtocolMessageType('BOGODiscount', (_message.Message,), {
  'DESCRIPTOR' : _BOGODISCOUNT,
  '__module__' : 'opencannabis.structs.pricing.SaleDescriptor_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.structs.pricing.BOGODiscount)
  })
_sym_db.RegisterMessage(BOGODiscount)

LoyaltyDiscount = _reflection.GeneratedProtocolMessageType('LoyaltyDiscount', (_message.Message,), {
  'DESCRIPTOR' : _LOYALTYDISCOUNT,
  '__module__' : 'opencannabis.structs.pricing.SaleDescriptor_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.structs.pricing.LoyaltyDiscount)
  })
_sym_db.RegisterMessage(LoyaltyDiscount)

SaleDescriptor = _reflection.GeneratedProtocolMessageType('SaleDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _SALEDESCRIPTOR,
  '__module__' : 'opencannabis.structs.pricing.SaleDescriptor_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.structs.pricing.SaleDescriptor)
  })
_sym_db.RegisterMessage(SaleDescriptor)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/base/ProductKind.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/base/ProductKind.proto',
  package='opencannabis.base',
  syntax='proto3',
  serialized_options=b'\n\033io.opencannabis.schema.baseB\017BaseProductKindH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#opencannabis/base/ProductKind.proto\x12\x11opencannabis.base*\x80\x01\n\x0bProductKind\x12\x0b\n\x07\x46LOWERS\x10\x00\x12\x0b\n\x07\x45\x44IBLES\x10\x01\x12\x0c\n\x08\x45XTRACTS\x10\x02\x12\x0c\n\x08PREROLLS\x10\x03\x12\x0e\n\nAPOTHECARY\x10\x04\x12\x0e\n\nCARTRIDGES\x10\x05\x12\n\n\x06PLANTS\x10\x06\x12\x0f\n\x0bMERCHANDISE\x10\x07\x42\x38\n\x1bio.opencannabis.schema.baseB\x0f\x42\x61seProductKindH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
)

_PRODUCTKIND = _descriptor.EnumDescriptor(
  name='ProductKind',
  full_name='opencannabis.base.ProductKind',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FLOWERS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EDIBLES', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXTRACTS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREROLLS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APOTHECARY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CARTRIDGES', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLANTS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MERCHANDISE', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=59,
  serialized_end=187,
)
_sym_db.RegisterEnumDescriptor(_PRODUCTKIND)

ProductKind = enum_type_wrapper.EnumTypeWrapper(_PRODUCTKIND)
FLOWERS = 0
EDIBLES = 1
EXTRACTS = 2
PREROLLS = 3
APOTHECARY = 4
CARTRIDGES = 5
PLANTS = 6
MERCHANDISE = 7


DESCRIPTOR.enum_types_by_name['ProductKind'] = _PRODUCTKIND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/products/Plant.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.base import ProductKey_pb2 as opencannabis_dot_base_dot_ProductKey__pb2
from opencannabis.content import MaterialsData_pb2 as opencannabis_dot_content_dot_MaterialsData__pb2
from opencannabis.content import ProductContent_pb2 as opencannabis_dot_content_dot_ProductContent__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/products/Plant.proto',
  package='opencannabis.products',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.productB\014PlantProductH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!opencannabis/products/Plant.proto\x12\x15opencannabis.products\x1a\"opencannabis/base/ProductKey.proto\x1a(opencannabis/content/MaterialsData.proto\x1a)opencannabis/content/ProductContent.proto\"\xbb\x02\n\x05Plant\x12*\n\x03key\x18\x01 \x01(\x0b\x32\x1d.opencannabis.base.ProductKey\x12/\n\x04type\x18\x02 \x01(\x0e\x32!.opencannabis.products.Plant.Type\x12\x33\n\x06origin\x18\x03 \x03(\x0b\x32#.opencannabis.base.ProductReference\x12\x35\n\x07product\x18\x04 \x01(\x0b\x32$.opencannabis.content.ProductContent\x12\x35\n\x08material\x18\x05 \x01(\x0b\x32#.opencannabis.content.MaterialsData\"2\n\x04Type\x12\x15\n\x11UNSPECIFIED_PLANT\x10\x00\x12\x08\n\x04SEED\x10\x01\x12\t\n\x05\x43LONE\x10\x02\x42\x38\n\x1eio.opencannabis.schema.productB\x0cPlantProductH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_base_dot_ProductKey__pb2.DESCRIPTOR,opencannabis_dot_content_dot_MaterialsData__pb2.DESCRIPTOR,opencannabis_dot_content_dot_ProductContent__pb2.DESCRIPTOR,])



_PLANT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='opencannabis.products.Plant.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_PLANT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLONE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=447,
  serialized_end=497,
)
_sym_db.RegisterEnumDescriptor(_PLANT_TYPE)


_PLANT = _descriptor.Descriptor(
  name='Plant',
  full_name='opencannabis.products.Plant',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.Plant.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.products.Plant.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin', full_name='opencannabis.products.Plant.origin', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product', full_name='opencannabis.products.Plant.product', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='material', full_name='opencannabis.products.Plant.material', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PLANT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=182,
  serialized_end=497,
)

_PLANT.fields_by_name['key'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTKEY
_PLANT.fields_by_name['type'].enum_type = _PLANT_TYPE
_PLANT.fields_by_name['origin'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTREFERENCE
_PLANT.fields_by_name['product'].message_type = opencannabis_dot_content_dot_ProductContent__pb2._PRODUCTCONTENT
_PLANT.fields_by_name['material'].message_type = opencannabis_dot_content_dot_MaterialsData__pb2._MATERIALSDATA
_PLANT_TYPE.containing_type = _PLANT
DESCRIPTOR.message_types_by_name['Plant'] = _PLANT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Plant = _reflection.GeneratedProtocolMessageType('Plant', (_message.Message,), {
  'DESCRIPTOR' : _PLANT,
  '__module__' : 'opencannabis.products.Plant_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.Plant)
  })
_sym_db.RegisterMessage(Plant)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/crypto/primitives/Keys.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.crypto.primitives import Integrity_pb2 as opencannabis_dot_crypto_dot_primitives_dot_Integrity__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/crypto/primitives/Keys.proto',
  package='opencannabis.crypto',
  syntax='proto3',
  serialized_options=b'\n(io.opencannabis.schema.crypto.primitivesH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)opencannabis/crypto/primitives/Keys.proto\x12\x13opencannabis.crypto\x1a.opencannabis/crypto/primitives/Integrity.proto\"z\n\x15\x42lockCipherParameters\x12\x33\n\talgorithm\x18\x01 \x01(\x0e\x32 .opencannabis.crypto.BlockCipher\x12,\n\x04mode\x18\x02 \x01(\x0e\x32\x1e.opencannabis.crypto.BlockMode\"\x94\x01\n\x16SymmetricKeyParameters\x12\x33\n\x06stream\x18\x01 \x01(\x0e\x32!.opencannabis.crypto.StreamCipherH\x00\x12;\n\x05\x62lock\x18\x02 \x01(\x0b\x32*.opencannabis.crypto.BlockCipherParametersH\x00\x42\x08\n\x06\x63ipher\"\x80\x01\n\x1b\x41symmetricKeypairParameters\x12\x31\n\x06scheme\x18\x01 \x01(\x0e\x32!.opencannabis.crypto.KeyingScheme\x12.\n\x0b\x66ingerprint\x18\x02 \x01(\x0b\x32\x19.opencannabis.crypto.Hash\"\xad\x02\n\rKeyParameters\x12\x11\n\talgorithm\x18\x01 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\x12\x0c\n\x04\x62its\x18\x03 \x01(\r\x12*\n\x04type\x18\x04 \x01(\x0e\x32\x1c.opencannabis.crypto.KeyType\x12\x38\n\x0b\x64isposition\x18\x05 \x01(\x0e\x32#.opencannabis.crypto.KeyDisposition\x12\x33\n\x06scheme\x18\n \x01(\x0e\x32!.opencannabis.crypto.KeyingSchemeH\x00\x12@\n\tsymmetric\x18\x0b \x01(\x0b\x32+.opencannabis.crypto.SymmetricKeyParametersH\x00\x42\x0e\n\x0c\x61rchitecture\"\x8c\x01\n\x14InitializationVector\x12;\n\x04mode\x18\x01 \x01(\x0e\x32-.opencannabis.crypto.InitializationVectorMode\x12\r\n\x03raw\x18\n \x01(\x0cH\x00\x12\r\n\x03\x62\x36\x34\x18\x0b \x01(\tH\x00\x12\x10\n\x06number\x18\x0c \x01(\rH\x00\x42\x07\n\x05value\"y\n\x0cSymmetricKey\x12\x0c\n\x04\x62its\x18\x01 \x01(\r\x12\x35\n\x02iv\x18\x02 \x01(\x0b\x32).opencannabis.crypto.InitializationVector\x12\r\n\x03raw\x18\n \x01(\x0cH\x00\x12\r\n\x03\x62\x36\x34\x18\x0b \x01(\tH\x00\x42\x06\n\x04\x64\x61ta\"\x97\x01\n\x0bKeyMaterial\x12.\n\x0b\x66ingerprint\x18\x01 \x01(\x0b\x32\x19.opencannabis.crypto.Hash\x12\x32\n\x06params\x18\x02 \x01(\x0b\x32\".opencannabis.crypto.KeyParameters\x12\r\n\x03raw\x18\n \x01(\x0cH\x00\x12\r\n\x03pem\x18\x0b \x01(\tH\x00\x42\x06\n\x04\x64\x61ta\"n\n\x07Keypair\x12\x30\n\x06public\x18\x01 \x01(\x0b\x32 .opencannabis.crypto.KeyMaterial\x12\x31\n\x07private\x18\x02 \x01(\x0b\x32 .opencannabis.crypto.KeyMaterial*(\n\x07KeyType\x12\r\n\tSYMMETRIC\x10\x00\x12\x0e\n\nASYMMETRIC\x10\x01*8\n\x0eKeyDisposition\x12\x0b\n\x07PRIVATE\x10\x00\x12\r\n\tEPHEMERAL\x10\x01\x12\n\n\x06PUBLIC\x10\x02*B\n\x0b\x42lockCipher\x12\x1c\n\x18UNSPECIFIED_BLOCK_CIPHER\x10\x00\x12\x07\n\x03\x41\x45S\x10\x01\x12\x0c\n\x08\x43\x41MELLIA\x10\x02*M\n\x0cStreamCipher\x12\x1d\n\x19UNSPECIFIED_STREAM_CIPHER\x10\x00\x12\x07\n\x03RC5\x10\x01\x12\x07\n\x03RC6\x10\x02\x12\x0c\n\x08\x43HACHA20\x10\x03*A\n\x0cKeyAgreement\x12\x1d\n\x19UNSPECIFIED_KEY_AGREEMENT\x10\x00\x12\x07\n\x03\x44HE\x10\x01\x12\t\n\x05\x45\x43\x44HE\x10\x02*x\n\tBlockMode\x12\x1a\n\x16UNSPECIFIED_BLOCK_MODE\x10\x00\x12\x07\n\x03\x45\x43\x42\x10\x01\x12\x07\n\x03\x43\x42\x43\x10\x02\x12\x07\n\x03\x43\x46\x42\x10\x03\x12\x07\n\x03OFB\x10\x04\x12\x07\n\x03\x43TR\x10\x05\x12\x07\n\x03\x43\x43M\x10\x06\x12\x07\n\x03GCM\x10\x07\x12\x07\n\x03XTS\x10\x08\x12\x07\n\x03KWP\x10\t*4\n\x0cKeyingScheme\x12\x07\n\x03RSA\x10\x00\x12\x07\n\x03\x45\x43\x43\x10\x01\x12\x07\n\x03\x44SA\x10\x02\x12\t\n\x05\x45\x64\x44SA\x10\x03*@\n\x18InitializationVectorMode\x12\r\n\tSTATIC_IV\x10\x00\x12\x08\n\x04TOTP\x10\x01\x12\x0b\n\x07\x43OUNTER\x10\x02\x42\x34\n(io.opencannabis.schema.crypto.primitivesH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_crypto_dot_primitives_dot_Integrity__pb2.DESCRIPTOR,])

_KEYTYPE = _descriptor.EnumDescriptor(
  name='KeyType',
  full_name='opencannabis.crypto.KeyType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SYMMETRIC', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASYMMETRIC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1356,
  serialized_end=1396,
)
_sym_db.RegisterEnumDescriptor(_KEYTYPE)

KeyType = enum_type_wrapper.EnumTypeWrapper(_KEYTYPE)
_KEYDISPOSITION = _descriptor.EnumDescriptor(
  name='KeyDisposition',
  full_name='opencannabis.crypto.KeyDisposition',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PRIVATE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EPHEMERAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PUBLIC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1398,
  serialized_end=1454,
)
_sym_db.RegisterEnumDescriptor(_KEYDISPOSITION)

KeyDisposition = enum_type_wrapper.EnumTypeWrapper(_KEYDISPOSITION)
_BLOCKCIPHER = _descriptor.EnumDescriptor(
  name='BlockCipher',
  full_name='opencannabis.crypto.BlockCipher',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_BLOCK_CIPHER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AES', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAMELLIA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1456,
  serialized_end=1522,
)
_sym_db.RegisterEnumDescriptor(_BLOCKCIPHER)

BlockCipher = enum_type_wrapper.EnumTypeWrapper(_BLOCKCIPHER)
_STREAMCIPHER = _descriptor.EnumDescriptor(
  name='StreamCipher',
  full_name='opencannabis.crypto.StreamCipher',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_STREAM_CIPHER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC5', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RC6', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHACHA20', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1524,
  serialized_end=1601,
)
_sym_db.RegisterEnumDescriptor(_STREAMCIPHER)

StreamCipher = enum_type_wrapper.EnumTypeWrapper(_STREAMCIPHER)
_KEYAGREEMENT = _descriptor.EnumDescriptor(
  name='KeyAgreement',
  full_name='opencannabis.crypto.KeyAgreement',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_KEY_AGREEMENT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DHE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ECDHE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1603,
  serialized_end=1668,
)
_sym_db.RegisterEnumDescriptor(_KEYAGREEMENT)

KeyAgreement = enum_type_wrapper.EnumTypeWrapper(_KEYAGREEMENT)
_BLOCKMODE = _descriptor.EnumDescriptor(
  name='BlockMode',
  full_name='opencannabis.crypto.BlockMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_BLOCK_MODE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ECB', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CFB', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OFB', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CTR', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CCM', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GCM', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='XTS', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KWP', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1670,
  serialized_end=1790,
)
_sym_db.RegisterEnumDescriptor(_BLOCKMODE)

BlockMode = enum_type_wrapper.EnumTypeWrapper(_BLOCKMODE)
_KEYINGSCHEME = _descriptor.EnumDescriptor(
  name='KeyingScheme',
  full_name='opencannabis.crypto.KeyingScheme',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RSA', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ECC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DSA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EdDSA', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1792,
  serialized_end=1844,
)
_sym_db.RegisterEnumDescriptor(_KEYINGSCHEME)

KeyingScheme = enum_type_wrapper.EnumTypeWrapper(_KEYINGSCHEME)
_INITIALIZATIONVECTORMODE = _descriptor.EnumDescriptor(
  name='InitializationVectorMode',
  full_name='opencannabis.crypto.InitializationVectorMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATIC_IV', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOTP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COUNTER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1846,
  serialized_end=1910,
)
_sym_db.RegisterEnumDescriptor(_INITIALIZATIONVECTORMODE)

InitializationVectorMode = enum_type_wrapper.EnumTypeWrapper(_INITIALIZATIONVECTORMODE)
SYMMETRIC = 0
ASYMMETRIC = 1
PRIVATE = 0
EPHEMERAL = 1
PUBLIC = 2
UNSPECIFIED_BLOCK_CIPHER = 0
AES = 1
CAMELLIA = 2
UNSPECIFIED_STREAM_CIPHER = 0
RC5 = 1
RC6 = 2
CHACHA20 = 3
UNSPECIFIED_KEY_AGREEMENT = 0
DHE = 1
ECDHE = 2
UNSPECIFIED_BLOCK_MODE = 0
ECB = 1
CBC = 2
CFB = 3
OFB = 4
CTR = 5
CCM = 6
GCM = 7
XTS = 8
KWP = 9
RSA = 0
ECC = 1
DSA = 2
EdDSA = 3
STATIC_IV = 0
TOTP = 1
COUNTER = 2



_BLOCKCIPHERPARAMETERS = _descriptor.Descriptor(
  name='BlockCipherParameters',
  full_name='opencannabis.crypto.BlockCipherParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='algorithm', full_name='opencannabis.crypto.BlockCipherParameters.algorithm', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='opencannabis.crypto.BlockCipherParameters.mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=236,
)


_SYMMETRICKEYPARAMETERS = _descriptor.Descriptor(
  name='SymmetricKeyParameters',
  full_name='opencannabis.crypto.SymmetricKeyParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream', full_name='opencannabis.crypto.SymmetricKeyParameters.stream', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block', full_name='opencannabis.crypto.SymmetricKeyParameters.block', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='cipher', full_name='opencannabis.crypto.SymmetricKeyParameters.cipher',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=239,
  serialized_end=387,
)


_ASYMMETRICKEYPAIRPARAMETERS = _descriptor.Descriptor(
  name='AsymmetricKeypairParameters',
  full_name='opencannabis.crypto.AsymmetricKeypairParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scheme', full_name='opencannabis.crypto.AsymmetricKeypairParameters.scheme', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fingerprint', full_name='opencannabis.crypto.AsymmetricKeypairParameters.fingerprint', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=390,
  serialized_end=518,
)


_KEYPARAMETERS = _descriptor.Descriptor(
  name='KeyParameters',
  full_name='opencannabis.crypto.KeyParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='algorithm', full_name='opencannabis.crypto.KeyParameters.algorithm', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='opencannabis.crypto.KeyParameters.format', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bits', full_name='opencannabis.crypto.KeyParameters.bits', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.crypto.KeyParameters.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disposition', full_name='opencannabis.crypto.KeyParameters.disposition', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheme', full_name='opencannabis.crypto.KeyParameters.scheme', index=5,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symmetric', full_name='opencannabis.crypto.KeyParameters.symmetric', index=6,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='architecture', full_name='opencannabis.crypto.KeyParameters.architecture',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=521,
  serialized_end=822,
)


_INITIALIZATIONVECTOR = _descriptor.Descriptor(
  name='InitializationVector',
  full_name='opencannabis.crypto.InitializationVector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='opencannabis.crypto.InitializationVector.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw', full_name='opencannabis.crypto.InitializationVector.raw', index=1,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b64', full_name='opencannabis.crypto.InitializationVector.b64', index=2,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='opencannabis.crypto.InitializationVector.number', index=3,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='opencannabis.crypto.InitializationVector.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=825,
  serialized_end=965,
)


_SYMMETRICKEY = _descriptor.Descriptor(
  name='SymmetricKey',
  full_name='opencannabis.crypto.SymmetricKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bits', full_name='opencannabis.crypto.SymmetricKey.bits', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iv', full_name='opencannabis.crypto.SymmetricKey.iv', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw', full_name='opencannabis.crypto.SymmetricKey.raw', index=2,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b64', full_name='opencannabis.crypto.SymmetricKey.b64', index=3,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='opencannabis.crypto.SymmetricKey.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=967,
  serialized_end=1088,
)


_KEYMATERIAL = _descriptor.Descriptor(
  name='KeyMaterial',
  full_name='opencannabis.crypto.KeyMaterial',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fingerprint', full_name='opencannabis.crypto.KeyMaterial.fingerprint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='opencannabis.crypto.KeyMaterial.params', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw', full_name='opencannabis.crypto.KeyMaterial.raw', index=2,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pem', full_name='opencannabis.crypto.KeyMaterial.pem', index=3,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='opencannabis.crypto.KeyMaterial.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1091,
  serialized_end=1242,
)


_KEYPAIR = _descriptor.Descriptor(
  name='Keypair',
  full_name='opencannabis.crypto.Keypair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='public', full_name='opencannabis.crypto.Keypair.public', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private', full_name='opencannabis.crypto.Keypair.private', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1244,
  serialized_end=1354,
)

_BLOCKCIPHERPARAMETERS.fields_by_name['algorithm'].enum_type = _BLOCKCIPHER
_BLOCKCIPHERPARAMETERS.fields_by_name['mode'].enum_type = _BLOCKMODE
_SYMMETRICKEYPARAMETERS.fields_by_name['stream'].enum_type = _STREAMCIPHER
_SYMMETRICKEYPARAMETERS.fields_by_name['block'].message_type = _BLOCKCIPHERPARAMETERS
_SYMMETRICKEYPARAMETERS.oneofs_by_name['cipher'].fields.append(
  _SYMMETRICKEYPARAMETERS.fields_by_name['stream'])
_SYMMETRICKEYPARAMETERS.fields_by_name['stream'].containing_oneof = _SYMMETRICKEYPARAMETERS.oneofs_by_name['cipher']
_SYMMETRICKEYPARAMETERS.oneofs_by_name['cipher'].fields.append(
  _SYMMETRICKEYPARAMETERS.fields_by_name['block'])
_SYMMETRICKEYPARAMETERS.fields_by_name['block'].containing_oneof = _SYMMETRICKEYPARAMETERS.oneofs_by_name['cipher']
_ASYMMETRICKEYPAIRPARAMETERS.fields_by_name['scheme'].enum_type = _KEYINGSCHEME
_ASYMMETRICKEYPAIRPARAMETERS.fields_by_name['fingerprint'].message_type = opencannabis_dot_crypto_dot_primitives_dot_Integrity__pb2._HASH
_KEYPARAMETERS.fields_by_name['type'].enum_type = _KEYTYPE
_KEYPARAMETERS.fields_by_name['disposition'].enum_type = _KEYDISPOSITION
_KEYPARAMETERS.fields_by_name['scheme'].enum_type = _KEYINGSCHEME
_KEYPARAMETERS.fields_by_name['symmetric'].message_type = _SYMMETRICKEYPARAMETERS
_KEYPARAMETERS.oneofs_by_name['architecture'].fields.append(
  _KEYPARAMETERS.fields_by_name['scheme'])
_KEYPARAMETERS.fields_by_name['scheme'].containing_oneof = _KEYPARAMETERS.oneofs_by_name['architecture']
_KEYPARAMETERS.oneofs_by_name['architecture'].fields.append(
  _KEYPARAMETERS.fields_by_name['symmetric'])
_KEYPARAMETERS.fields_by_name['symmetric'].containing_oneof = _KEYPARAMETERS.oneofs_by_name['architecture']
_INITIALIZATIONVECTOR.fields_by_name['mode'].enum_type = _INITIALIZATIONVECTORMODE
_INITIALIZATIONVECTOR.oneofs_by_name['value'].fields.append(
  _INITIALIZATIONVECTOR.fields_by_name['raw'])
_INITIALIZATIONVECTOR.fields_by_name['raw'].containing_oneof = _INITIALIZATIONVECTOR.oneofs_by_name['value']
_INITIALIZATIONVECTOR.oneofs_by_name['value'].fields.append(
  _INITIALIZATIONVECTOR.fields_by_name['b64'])
_INITIALIZATIONVECTOR.fields_by_name['b64'].containing_oneof = _INITIALIZATIONVECTOR.oneofs_by_name['value']
_INITIALIZATIONVECTOR.oneofs_by_name['value'].fields.append(
  _INITIALIZATIONVECTOR.fields_by_name['number'])
_INITIALIZATIONVECTOR.fields_by_name['number'].containing_oneof = _INITIALIZATIONVECTOR.oneofs_by_name['value']
_SYMMETRICKEY.fields_by_name['iv'].message_type = _INITIALIZATIONVECTOR
_SYMMETRICKEY.oneofs_by_name['data'].fields.append(
  _SYMMETRICKEY.fields_by_name['raw'])
_SYMMETRICKEY.fields_by_name['raw'].containing_oneof = _SYMMETRICKEY.oneofs_by_name['data']
_SYMMETRICKEY.oneofs_by_name['data'].fields.append(
  _SYMMETRICKEY.fields_by_name['b64'])
_SYMMETRICKEY.fields_by_name['b64'].containing_oneof = _SYMMETRICKEY.oneofs_by_name['data']
_KEYMATERIAL.fields_by_name['fingerprint'].message_type = opencannabis_dot_crypto_dot_primitives_dot_Integrity__pb2._HASH
_KEYMATERIAL.fields_by_name['params'].message_type = _KEYPARAMETERS
_KEYMATERIAL.oneofs_by_name['data'].fields.append(
  _KEYMATERIAL.fields_by_name['raw'])
_KEYMATERIAL.fields_by_name['raw'].containing_oneof = _KEYMATERIAL.oneofs_by_name['data']
_KEYMATERIAL.oneofs_by_name['data'].fields.append(
  _KEYMATERIAL.fields_by_name['pem'])
_KEYMATERIAL.fields_by_name['pem'].containing_oneof = _KEYMATERIAL.oneofs_by_name['data']
_KEYPAIR.fields_by_name['public'].message_type = _KEYMATERIAL
_KEYPAIR.fields_by_name['private'].message_type = _KEYMATERIAL
DESCRIPTOR.message_types_by_name['BlockCipherParameters'] = _BLOCKCIPHERPARAMETERS
DESCRIPTOR.message_types_by_name['SymmetricKeyParameters'] = _SYMMETRICKEYPARAMETERS
DESCRIPTOR.message_types_by_name['AsymmetricKeypairParameters'] = _ASYMMETRICKEYPAIRPARAMETERS
DESCRIPTOR.message_types_by_name['KeyParameters'] = _KEYPARAMETERS
DESCRIPTOR.message_types_by_name['InitializationVector'] = _INITIALIZATIONVECTOR
DESCRIPTOR.message_types_by_name['SymmetricKey'] = _SYMMETRICKEY
DESCRIPTOR.message_types_by_name['KeyMaterial'] = _KEYMATERIAL
DESCRIPTOR.message_types_by_name['Keypair'] = _KEYPAIR
DESCRIPTOR.enum_types_by_name['KeyType'] = _KEYTYPE
DESCRIPTOR.enum_types_by_name['KeyDisposition'] = _KEYDISPOSITION
DESCRIPTOR.enum_types_by_name['BlockCipher'] = _BLOCKCIPHER
DESCRIPTOR.enum_types_by_name['StreamCipher'] = _STREAMCIPHER
DESCRIPTOR.enum_types_by_name['KeyAgreement'] = _KEYAGREEMENT
DESCRIPTOR.enum_types_by_name['BlockMode'] = _BLOCKMODE
DESCRIPTOR.enum_types_by_name['KeyingScheme'] = _KEYINGSCHEME
DESCRIPTOR.enum_types_by_name['InitializationVectorMode'] = _INITIALIZATIONVECTORMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BlockCipherParameters = _reflection.GeneratedProtocolMessageType('BlockCipherParameters', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKCIPHERPARAMETERS,
  '__module__' : 'opencannabis.crypto.primitives.Keys_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.crypto.BlockCipherParameters)
  })
_sym_db.RegisterMessage(BlockCipherParameters)

SymmetricKeyParameters = _reflection.GeneratedProtocolMessageType('SymmetricKeyParameters', (_message.Message,), {
  'DESCRIPTOR' : _SYMMETRICKEYPARAMETERS,
  '__module__' : 'opencannabis.crypto.primitives.Keys_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.crypto.SymmetricKeyParameters)
  })
_sym_db.RegisterMessage(SymmetricKeyParameters)

AsymmetricKeypairParameters = _reflection.GeneratedProtocolMessageType('AsymmetricKeypairParameters', (_message.Message,), {
  'DESCRIPTOR' : _ASYMMETRICKEYPAIRPARAMETERS,
  '__module__' : 'opencannabis.crypto.primitives.Keys_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.crypto.AsymmetricKeypairParameters)
  })
_sym_db.RegisterMessage(AsymmetricKeypairParameters)

KeyParameters = _reflection.GeneratedProtocolMessageType('KeyParameters', (_message.Message,), {
  'DESCRIPTOR' : _KEYPARAMETERS,
  '__module__' : 'opencannabis.crypto.primitives.Keys_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.crypto.KeyParameters)
  })
_sym_db.RegisterMessage(KeyParameters)

InitializationVector = _reflection.GeneratedProtocolMessageType('InitializationVector', (_message.Message,), {
  'DESCRIPTOR' : _INITIALIZATIONVECTOR,
  '__module__' : 'opencannabis.crypto.primitives.Keys_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.crypto.InitializationVector)
  })
_sym_db.RegisterMessage(InitializationVector)

SymmetricKey = _reflection.GeneratedProtocolMessageType('SymmetricKey', (_message.Message,), {
  'DESCRIPTOR' : _SYMMETRICKEY,
  '__module__' : 'opencannabis.crypto.primitives.Keys_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.crypto.SymmetricKey)
  })
_sym_db.RegisterMessage(SymmetricKey)

KeyMaterial = _reflection.GeneratedProtocolMessageType('KeyMaterial', (_message.Message,), {
  'DESCRIPTOR' : _KEYMATERIAL,
  '__module__' : 'opencannabis.crypto.primitives.Keys_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.crypto.KeyMaterial)
  })
_sym_db.RegisterMessage(KeyMaterial)

Keypair = _reflection.GeneratedProtocolMessageType('Keypair', (_message.Message,), {
  'DESCRIPTOR' : _KEYPAIR,
  '__module__' : 'opencannabis.crypto.primitives.Keys_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.crypto.Keypair)
  })
_sym_db.RegisterMessage(Keypair)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/structs/Genetics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.base import ProductKey_pb2 as opencannabis_dot_base_dot_ProductKey__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/structs/Genetics.proto',
  package='opencannabis.structs',
  syntax='proto3',
  serialized_options=b'\n%io.opencannabis.schema.product.structB\017GeneticsStructsH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#opencannabis/structs/Genetics.proto\x12\x14opencannabis.structs\x1a\"opencannabis/base/ProductKey.proto\"r\n\x08Genetics\x12\x31\n\x04male\x18\x01 \x01(\x0b\x32#.opencannabis.base.ProductReference\x12\x33\n\x06\x66\x65male\x18\x02 \x01(\x0b\x32#.opencannabis.base.ProductReferenceBB\n%io.opencannabis.schema.product.structB\x0fGeneticsStructsH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_base_dot_ProductKey__pb2.DESCRIPTOR,])




_GENETICS = _descriptor.Descriptor(
  name='Genetics',
  full_name='opencannabis.structs.Genetics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='male', full_name='opencannabis.structs.Genetics.male', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='female', full_name='opencannabis.structs.Genetics.female', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=211,
)

_GENETICS.fields_by_name['male'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTREFERENCE
_GENETICS.fields_by_name['female'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTREFERENCE
DESCRIPTOR.message_types_by_name['Genetics'] = _GENETICS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Genetics = _reflection.GeneratedProtocolMessageType('Genetics', (_message.Message,), {
  'DESCRIPTOR' : _GENETICS,
  '__module__' : 'opencannabis.structs.Genetics_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.structs.Genetics)
  })
_sym_db.RegisterMessage(Genetics)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/content/Data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/content/Data.proto',
  package='opencannabis.content',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.contentH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fopencannabis/content/Data.proto\x12\x14opencannabis.content*\xa8\x01\n\nDataFormat\x12\x12\n\x0eUNKNOWN_FORMAT\x10\x00\x12\x07\n\x03\x43SV\x10\n\x12\x07\n\x03TSV\x10\x0b\x12\r\n\tEXCEL_CSV\x10\x0c\x12\r\n\tEXCEL_XLS\x10\r\x12\x0e\n\nEXCEL_XLSX\x10\x0e\x12\x0b\n\x07MSGPACK\x10\x14\x12\x08\n\x04\x41VRO\x10\x1e\x12\x07\n\x03SQL\x10(\x12\x08\n\x04JSON\x10\x32\x12\x0c\n\x08OCP_TEXT\x10=\x12\x0e\n\nOCP_BINARY\x10>B*\n\x1eio.opencannabis.schema.contentH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
)

_DATAFORMAT = _descriptor.EnumDescriptor(
  name='DataFormat',
  full_name='opencannabis.content.DataFormat',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_FORMAT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CSV', index=1, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TSV', index=2, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXCEL_CSV', index=3, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXCEL_XLS', index=4, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXCEL_XLSX', index=5, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSGPACK', index=6, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AVRO', index=7, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SQL', index=8, number=40,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JSON', index=9, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OCP_TEXT', index=10, number=61,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OCP_BINARY', index=11, number=62,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=58,
  serialized_end=226,
)
_sym_db.RegisterEnumDescriptor(_DATAFORMAT)

DataFormat = enum_type_wrapper.EnumTypeWrapper(_DATAFORMAT)
UNKNOWN_FORMAT = 0
CSV = 10
TSV = 11
EXCEL_CSV = 12
EXCEL_XLS = 13
EXCEL_XLSX = 14
MSGPACK = 20
AVRO = 30
SQL = 40
JSON = 50
OCP_TEXT = 61
OCP_BINARY = 62


DESCRIPTOR.enum_types_by_name['DataFormat'] = _DATAFORMAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
